@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2013-2021 Canonical, Ltd.
- * Copyright (C) 2021-2024 Colin Ian King
+ * Copyright (C) 2021-2025 Colin Ian King
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -97,7 +97,6 @@
  *  Standard includes, assume we have this as the
  *  minimal standard baseline
  */
-#include <dirent.h>
 #include <errno.h>
 #include <fcntl.h>
 #include <inttypes.h>
@@ -110,7 +109,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <time.h>
 #include <unistd.h>
 #if defined(HAVE_STRINGS_H)
 #include <strings.h>
@@ -129,14 +127,10 @@
  *  Various sys include files
  */
 #include <sys/mman.h>
-#include <sys/resource.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/wait.h>
-#if defined(HAVE_SYS_PARAM_H)
-#include <sys/param.h>
-#endif
 #if defined(HAVE_SYSCALL_H)
 #include <sys/syscall.h>
 #endif
@@ -158,6 +152,8 @@
 #define STRESS_STRESSOR_STATUS_BAD_METRICS	(3)
 #define STRESS_STRESSOR_STATUS_MAX		(4)
 
+#define STRESS_MAX_PERMUTATIONS			(20)
+
 /* Some Solaris systems don't have NAME_MAX */
 #if !defined(NAME_MAX)
 #if defined(MAXNAMELEN)
@@ -177,6 +173,7 @@ typedef struct stress_pid {
 	pid_t pid;			/* PID of process */
 	pid_t oomable_child;		/* oomable child pid, zero = none */
 	volatile uint8_t state;		/* sync start state */
+	bool reaped;			/* successfully waited for */
 } stress_pid_t;
 
 typedef struct {
@@ -268,6 +265,7 @@ typedef struct stress_stressor_info {
 #define UNEXPECTED
 #endif
 
+/* Voidification of returns */
 #define VOID_RET(type, x)	\
 do {				\
 	type void_ret = x;	\
@@ -415,7 +413,6 @@ typedef union {
 
 typedef uint32_t stress_class_t;
 
-
 typedef struct {
 	void *lock;			/* optional lock */
 	double	duration;		/* time per op */
@@ -508,7 +505,6 @@ extern const char stress_config[];
 #define MAXIMIZED_FILE_SIZE	((sizeof(off_t) < 8) ? MAX_FILE_LIMIT : MAX_32)
 
 /* Stressor defaults */
-
 #define TIMEOUT_NOT_SET		(~0ULL)
 #define UNDEFINED		(-1)
 #define PAGE_MAPPED		(0x01)
@@ -620,6 +616,9 @@ typedef struct {
 		void *lock;		/* protection lock */
 	} warn_once;
 	union {
+#if defined(HAVE_INT128_T)
+		__uint128_t val128[4] ALIGN64;
+#endif
 		uint64_t val64[8] ALIGN64;
 		uint32_t val32[16] ALIGN64;
 		uint16_t val16[32] ALIGN64;
@@ -678,7 +677,7 @@ typedef struct stress {
 	const stressor_info_t *info;	/* stress test info */
 	const short int short_getopt;	/* getopt short option */
 	const stress_op_t op;		/* ops option */
-	const char *name;		/* name of stress test */
+	char name[16];			/* stressor function name */
 } stress_t;
 
 /* Pointer to current running stressor proc info */
@@ -691,6 +690,7 @@ extern uint64_t	g_opt_timeout;		/* timeout in seconds */
 extern uint64_t	g_opt_flags;		/* option flags */
 extern volatile bool g_stress_continue_flag; /* false to exit stressor */
 extern jmp_buf g_error_env;		/* parsing error env */
+extern void *g_nowt;			/* void pointer to NULL */
 
 /*
  *  stress_continue_flag()
@@ -712,7 +712,7 @@ static inline void ALWAYS_INLINE OPTIMIZE3 stress_continue_set_flag(const bool s
 
 /*
  *  stress_bogo_add()
- *	add inc to the stessor bogo ops counter
+ *	add inc to the stressor bogo ops counter
  *	NOTE: try to only add to the counter inside a stressor
  *	and not a child process of a stressor. If one has to add to
  *	the counter in a child and the child is force KILL'd then indicate
@@ -729,7 +729,7 @@ static inline void ALWAYS_INLINE OPTIMIZE3 stress_bogo_add(stress_args_t *args,
 
 /*
  *  stress_bogo_inc()
- *	increment the stessor bogo ops counter
+ *	increment the stressor bogo ops counter
  *	NOTE: try to only increment the counter inside a stressor
  *	and not a child process of a stressor. If one has to increment
  *	the counter in a child and the child is force KILL'd then indicate
@@ -746,7 +746,7 @@ static inline void ALWAYS_INLINE OPTIMIZE3 stress_bogo_inc(stress_args_t *args)
 
 /*
  *  stress_bogo_get()
- *	get the stessor bogo ops counter
+ *	get the stressor bogo ops counter
  */
 static inline uint64_t ALWAYS_INLINE OPTIMIZE3 stress_bogo_get(stress_args_t *args)
 {
@@ -764,7 +764,7 @@ static inline void ALWAYS_INLINE OPTIMIZE3 stress_bogo_ready(stress_args_t *args
 
 /*
  *  stress_bogo_set()
- *	set the stessor bogo ops counter
+ *	set the stressor bogo ops counter
  *	NOTE: try to only set the counter inside a stressor
  *	and not a child process of a stressor. If one has to set
  *	the counter in a child and the child is force KILL'd then indicate
@@ -805,7 +805,7 @@ static inline bool ALWAYS_INLINE OPTIMIZE3 stress_continue(stress_args_t *args)
 
 /*
  *  stress_bogo_add_lock()
- *	add val to the stessor bogo ops counter with lock, return true
+ *	add val to the stressor bogo ops counter with lock, return true
  *	if stress_continue is true
  */
 static inline void stress_bogo_add_lock(stress_args_t *args, void *lock, const int64_t val)
@@ -823,7 +823,7 @@ static inline void stress_bogo_add_lock(stress_args_t *args, void *lock, const i
 
 /*
  *  stress_bogo_inc_lock()
- *	increment the stessor bogo ops counter with lock, return true
+ *	increment the stressor bogo ops counter with lock, return true
  *	if stress_continue is true
  */
 static inline bool stress_bogo_inc_lock(stress_args_t *args, void *lock, const bool inc)
